@@ -46,7 +46,7 @@ static int minimumListWidth(const QListWidget *list)
     for (int i = 0; i < list->count(); i++) {
         int itemWidth = list->visualItemRect(list->item(i)).width();
         // ...and add a space on both sides for not too tight look.
-        itemWidth += list->fontMetrics().width(QLatin1Char(' ')) * 2;
+        itemWidth += list->fontMetrics().horizontalAdvance(QLatin1Char(' ')) * 2;
         w = qMax(w, itemWidth);
     }
     if (w == 0) {
@@ -882,8 +882,9 @@ void KFontChooser::Private::setupDisplay()
 
     // 1st family fallback.
     if (i == numEntries) {
-        if (family.contains(QLatin1Char('['))) {
-            family = family.left(family.indexOf(QLatin1Char('['))).trimmed();
+        const int bracketPos = family.indexOf(QLatin1Char('['));
+        if (bracketPos != -1) {
+            family = family.leftRef(bracketPos).trimmed().toString();
             for (i = 0; i < numEntries; ++i) {
                 if (family == qtFamilies[familyListBox->item(i)->text()].toLower()) {
                     familyListBox->setCurrentRow(i);
@@ -895,7 +896,7 @@ void KFontChooser::Private::setupDisplay()
 
     // 2nd family fallback.
     if (i == numEntries) {
-        QString fallback = family + QStringLiteral(" [");
+        QString fallback = family + QLatin1String(" [");
         for (i = 0; i < numEntries; ++i) {
             if (qtFamilies[familyListBox->item(i)->text()].toLower().startsWith(fallback)) {
                 familyListBox->setCurrentRow(i);
